abacusai.feature_group_document — AbacusAI documentation

# abacusai.feature_group_document

## Classes

`AbstractApiClass` |
`FeatureGroupDocument` | A document of a feature group.

## Module Contents

class abacusai.feature_group_document.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.feature_group_document.FeatureGroupDocument(client, featureGroupId=None, docId=None, status=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A document of a feature group.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupId (str) – The ID of the feature group this row belongs to.

    - docId (str) – Unique document id

    - status (str) – The status of the document processing

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict